@@ -185,3 +185,12 @@ class Arange(TunableValue):
 class Linspace(TunableValue):
     def __init__(self, start, stop, num):
         self.values = linspace(start=start, stop=stop, num=num).astype('float').tolist()
+
+
+class GeometricProgression(TunableValue):
+    def __init__(self, start, stop, multiplier):
+        val = start
+        self.values = []
+        while val <= stop:
+            self.values.append(val)
+            val *= multiplier
